==> firekeeper-0.2.6.tar.gz: firekeeper-0.2.6/components/fkHttpChannel.h <==
/*$Id: fkHttpChannel.h,v 1.11 2006/11/04 21:09:25 jwrobel Exp $*/
/* ***** BEGIN LICENSE BLOCK *****
 *  This file is part of Firekeeper.
 *
 *  Copyright (C) 2006 Jan Wrobel <wrobel@blues.ath.cx>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * ***** END LICENSE BLOCK ***** */

#ifndef FKHTTPCHANNEL_H
#define FKHTTPCHANNEL_H

#include "nsISupports.h"
#include "nsISupportsUtils.h"
#include "nsWeakReference.h"

#include "nsIHttpChannel.h"
#include "nsIHttpChannelInternal.h"
#include "nsIStreamListener.h"
#include "nsICachingChannel.h"
#include "nsIUploadChannel.h"
#include "nsICacheListener.h"
#include "nsIEncodedChannel.h"
#include "nsITransport.h"
#include "nsIResumableChannel.h"
#include "nsISupportsPriority.h"
#include "nsIProtocolProxyCallback.h"
#include "nsIWritablePropertyBag.h"
#include "nsIWritablePropertyBag2.h"

#include "fkISentence.h"
#include "fkSentence.h"

#include "Rules.h"
#include "ActiveRuleSet.h"
#include "Error.h"

/*
  Firekeeper's HttpChannel created by fkHttpHandler.
  Passes all calls to oryginal Mozilla's HttpChannel with an exception
  of AsyncOpen call which creates StreamListener able to audit data downloaded
  through this stream.
 */
class fkHttpChannel : public nsIHttpChannel
                    , public nsIHttpChannelInternal
                    , public nsIStreamListener
                    , public nsICachingChannel
                    , public nsIUploadChannel
                    , public nsICacheListener
                    , public nsIEncodedChannel
                    , public nsITransportEventSink
                    , public nsIResumableChannel
                    , public nsISupportsPriority
                    , public nsIProtocolProxyCallback
		    , public nsIWritablePropertyBag
		    , public nsIWritablePropertyBag2
{
public:
//  NS_DECL_ISUPPORTS_INHERITED
    NS_DECL_ISUPPORTS

    NS_DECL_NSIREQUEST
    NS_DECL_NSICHANNEL
    NS_DECL_NSIHTTPCHANNEL
    NS_DECL_NSIREQUESTOBSERVER
    NS_DECL_NSISTREAMLISTENER
    NS_DECL_NSICACHINGCHANNEL
    NS_DECL_NSIUPLOADCHANNEL
    NS_DECL_NSICACHELISTENER
    NS_DECL_NSIENCODEDCHANNEL
    NS_DECL_NSIHTTPCHANNELINTERNAL
    NS_DECL_NSITRANSPORTEVENTSINK
    NS_DECL_NSIRESUMABLECHANNEL
    NS_DECL_NSISUPPORTSPRIORITY
    NS_DECL_NSIPROTOCOLPROXYCALLBACK

    NS_DECL_NSIPROPERTYBAG
    NS_DECL_NSIPROPERTYBAG2
    NS_DECL_NSIWRITABLEPROPERTYBAG
    NS_DECL_NSIWRITABLEPROPERTYBAG2


    fkHttpChannel(nsIChannel *origChannel, fkISentence *sentence, 
		  ActiveRuleSet *connRules);

    virtual ~fkHttpChannel();

 private:

    /*Rules used to check data*/
    ActiveRuleSet *connRules;
    
    nsCOMPtr<fkISentence> sentence;
    
    nsCOMPtr<nsIRequest> origRequest;
    nsCOMPtr<nsIChannel> origChannel;
    nsCOMPtr<nsIHttpChannel> origHttpChannel;    
    nsCOMPtr<nsIRequestObserver> origRequestObserver;
    nsCOMPtr<nsIStreamListener> origStreamListener;
    nsCOMPtr<nsICachingChannel> origCachingChannel;
    nsCOMPtr<nsIUploadChannel> origUploadChannel;
    nsCOMPtr<nsICacheListener> origCacheListener;
    nsCOMPtr<nsIEncodedChannel> origEncodedChannel;
    nsCOMPtr<nsIHttpChannelInternal> origHttpChannelInternal;
    nsCOMPtr<nsITransportEventSink> origTransportEventSink;
    nsCOMPtr<nsIResumableChannel> origResumableChannel;
    nsCOMPtr<nsISupportsPriority> origSupportsPriority;
    nsCOMPtr<nsIProtocolProxyCallback> origProtocolProxyCallback;

    nsCOMPtr<nsIPropertyBag> origPropertyBag;
    nsCOMPtr<nsIPropertyBag2> origPropertyBag2;
    nsCOMPtr<nsIWritablePropertyBag> origWritablePropertyBag;
    nsCOMPtr<nsIWritablePropertyBag2> origWritablePropertyBag2;


    void checkResult(nsresult rv, const char *iname){
	    if (NS_FAILED(rv))
		    err_msg("Can't get reference to %s interface %d", 
			    iname, rv);    
    }
    
};


#endif

==> firekeeper-0.2.11.tar.gz: firekeeper-0.2.11/components/fkHttpChannel.h <==
/*$Id: fkHttpChannel.h,v 1.14 2007/07/22 20:05:21 jwrobel Exp $*/
/* ***** BEGIN LICENSE BLOCK *****
 *  This file is part of Firekeeper.
 *
 *  Copyright (C) 2006,2007 Jan Wrobel <wrobel@blues.ath.cx>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * ***** END LICENSE BLOCK ***** */

#ifndef FKHTTPCHANNEL_H
#define FKHTTPCHANNEL_H

#include "nsISupports.h"
#include "nsISupportsUtils.h"
#include "nsWeakReference.h"

#include "nsIHttpChannel.h"
#include "nsIHttpChannelInternal.h"
#include "nsIStreamListener.h"
#include "nsICachingChannel.h"
#include "nsIUploadChannel.h"
#include "nsICacheListener.h"
#include "nsIEncodedChannel.h"
#include "nsITransport.h"
#include "nsIResumableChannel.h"
#include "nsISupportsPriority.h"
#include "nsIProtocolProxyCallback.h"
#include "nsIWritablePropertyBag.h"
#include "nsIWritablePropertyBag2.h"

#include "fkISentence.h"
#include "fkSentence.h"
#include "fkCallbacks.h"
#include "fkLoadGroup.h"

#include "Rules.h"
#include "ActiveRuleSet.h"
#include "Error.h"


/*
  Firekeeper's HttpChannel created by fkHttpHandler.
  Passes all calls to oryginal Mozilla's HttpChannel with an exception
  of AsyncOpen call which creates StreamListener able to audit data downloaded
  through this stream.
 */
class fkHttpChannel : public nsIHttpChannel
                    , public nsIHttpChannelInternal
                    , public nsIStreamListener
                    , public nsICachingChannel
                    , public nsIUploadChannel
                    , public nsICacheListener
                    , public nsIEncodedChannel
                    , public nsITransportEventSink
                    , public nsIResumableChannel
                    , public nsISupportsPriority
                    , public nsIProtocolProxyCallback
		    , public nsIWritablePropertyBag
                    , public nsIWritablePropertyBag2
                    
{
public:
//  NS_DECL_ISUPPORTS_INHERITED
    NS_DECL_ISUPPORTS

    NS_DECL_NSIREQUEST
    NS_DECL_NSICHANNEL
    NS_DECL_NSIHTTPCHANNEL
    NS_DECL_NSIREQUESTOBSERVER
    NS_DECL_NSISTREAMLISTENER
    NS_DECL_NSICACHINGCHANNEL
    NS_DECL_NSIUPLOADCHANNEL
    NS_DECL_NSICACHELISTENER
    NS_DECL_NSIENCODEDCHANNEL
    NS_DECL_NSIHTTPCHANNELINTERNAL
    NS_DECL_NSITRANSPORTEVENTSINK
    NS_DECL_NSIRESUMABLECHANNEL
    NS_DECL_NSISUPPORTSPRIORITY
    NS_DECL_NSIPROTOCOLPROXYCALLBACK

    NS_DECL_NSIPROPERTYBAG
    NS_DECL_NSIPROPERTYBAG2
    NS_DECL_NSIWRITABLEPROPERTYBAG
    NS_DECL_NSIWRITABLEPROPERTYBAG2


    fkHttpChannel(nsIChannel *origChannel, fkISentence *sentence, 
		  ActiveRuleSet *connRules);

    virtual ~fkHttpChannel();

    NS_IMETHODIMP init();
    
 private:

    /*Rules used to check data*/
    ActiveRuleSet *connRules;
    

    nsCOMPtr<fkISentence> sentence;
    
    nsCOMPtr<nsIRequest> origRequest;
    nsCOMPtr<nsIChannel> origChannel;
    nsCOMPtr<nsIHttpChannel> origHttpChannel;    
    nsCOMPtr<nsIRequestObserver> origRequestObserver;
    nsCOMPtr<nsIStreamListener> origStreamListener;
    nsCOMPtr<nsICachingChannel> origCachingChannel;
    nsCOMPtr<nsIUploadChannel> origUploadChannel;
    nsCOMPtr<nsICacheListener> origCacheListener;
    nsCOMPtr<nsIEncodedChannel> origEncodedChannel;
    nsCOMPtr<nsIHttpChannelInternal> origHttpChannelInternal;
    nsCOMPtr<nsITransportEventSink> origTransportEventSink;
    nsCOMPtr<nsIResumableChannel> origResumableChannel;
    nsCOMPtr<nsISupportsPriority> origSupportsPriority;
    nsCOMPtr<nsIProtocolProxyCallback> origProtocolProxyCallback;

    nsCOMPtr<nsIPropertyBag> origPropertyBag;
    nsCOMPtr<nsIPropertyBag2> origPropertyBag2;
    nsCOMPtr<nsIWritablePropertyBag> origWritablePropertyBag;
    nsCOMPtr<nsIWritablePropertyBag2> origWritablePropertyBag2;

    //nsCOMPtr<nsILoadGroup> origLoadGroup;
    //nsCOMPtr<nsIInterfaceRequestor> origCallbacks;
    
    //fkCallbacks *callbacksProxy;
    nsCOMPtr<nsIInterfaceRequestor> callbacksProxy;
    nsCOMPtr<nsILoadGroup> loadGroupProxy;

    //nsILoadGroup *loadGroupProxy;
	    

    void checkResult(nsresult rv, const char *iname){
	    if (NS_FAILED(rv))
		    err_msg("Can't get reference to %s interface %d", 
			    iname, rv);    
    }
    
};


#endif
